import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';

import 'views/action_button.example.dart';
import 'views/animation.example.dart';
import 'views/balance.example.dart';
import 'views/button.example.dart';
import 'views/card.example.dart';
import 'views/checkbox.example.dart';
import 'views/dropdown_button.example.dart';
import 'views/expansion_panel.example.dart';
import 'views/info_card.example.dart';
import 'views/radio_button.example.dart';
import 'views/rating.example.dart';
import 'views/switch.example.dart';
import 'views/navigation.example.dart';
import 'views/text_field.example.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'Senior Design System Showcase',
      home: HomePage(),
    );
  }
}

class HomePage extends StatelessWidget {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  final PageController _pageController = PageController();
  final Map<String, Widget> _pages = {
    'Card': CardExample(),
    'App Bar/Tab Bar/Bottom Bar': NavigationExample(),
    'Action Button': ActionButtonExample(),
    'Button': ButtonExample(),
    'Checkbox': CheckboxExample(),
    'Radio Button': RadioButtonExample(),
    'Rating': RatingExample(),
    'Dropdown Button': DropdownButtonExample(),
    'Text Field': TextFieldExample(),
    'Switch': SwitchExample(),
    'Info Card': InfoCardExample(),
    'Balance': BalanceExample(),
    'Expansion Panel': ExpansionPanelExample(),
    'Animation': AnimationExample(),
  };

  HomePage({
    Key? key,
  }) : super(key: key);

  ListView _getListViewMenu() {
    return ListView(
      children: _pages.keys
          .toList()
          .asMap()
          .map((pos, title) => MapEntry(
              title,
              ListTile(
                title: Text(title),
                onTap: () => _jumpToPage(page: pos),
              )))
          .values
          .toList(),
    );
  }

  void _jumpToPage({required int page}) {
    _pageController.jumpToPage(page);
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        key: _scaffoldKey,
        appBar: SeniorAppBarPage(
          title: 'SDS Mobile',
          leading: SeniorAppBarAction(
            icon: FontAwesomeIcons.bars,
            onPressed: () => _scaffoldKey.currentState!.openDrawer(),
          ),
        ),
        drawer: Drawer(child: _getListViewMenu()),
        body: PageView.builder(
          controller: _pageController,
          itemBuilder: (context, position) => _pages.values.toList()[position],
          itemCount: _pages.length,
        ),
      ),
    );
  }
}