import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class RatingExample extends StatefulWidget {
  const RatingExample({Key? key}) : super(key: key);

  @override
  _RatingExampleState createState() => _RatingExampleState();
}

class _RatingExampleState extends State<RatingExample> {
  bool _isDisabled = false;
  double _ratingOne = 3.0;
  double _ratingTwo = 3.5;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Rating Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Apenas avaliações inteiras',
                      content: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          allowHalfRating: false,
                          direction: Axis.horizontal,
                          initialRating: _ratingOne,
                          disabled: _isDisabled,
                          onRatingUpdate: (double rating) {
                            setState(() {
                              _ratingOne = rating;
                            });
                          },
                        ),
                      ),
                    ),
                    Panel(
                      title: 'Meia-avaliação',
                      content: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          allowHalfRating: true,
                          direction: Axis.horizontal,
                          initialRating: _ratingTwo,
                          disabled: _isDisabled,
                          onRatingUpdate: (double rating) {
                            setState(() {
                              _ratingTwo = rating;
                            });
                          },
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Column(
                children: [
                  Text(
                    'Primeira avaliação: $_ratingOne',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                  Text(
                    'Segunda avaliação: $_ratingTwo',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                ],
              )
            ],
          ),
        ),
      ),
    );
  }
}
