# SeniorButton class

Use SeniorButton para adicionar botões com as definições do Senior Design System no seu layout.

## Tipos de botões

Podem ser criados três tipos de botões, sendo eles:

* Primary
* Secondary
* Ghost

| Type      | Enum                       |
| --------- | -------------------------- |
| Primary   | SeniorButtonType.primary   |
| Secondary | SeniorButtonType.secondary |
| Ghost     | SeniorButtonType.ghost     |

## Tamanho dos botões

Os botões podem ter variações de tamanho. Apenas a altura do botão é alterada. Para alterações na largura confira a propriedade fullLength. As variações disponíveis são:  

* Small
* Big

| Type  | Enum                   |
| ----- | ---------------------- |
| Small | SeniorButtonSize.small |
| Big   | SeniorButtonSize.big   |

## Herança

Object > DiagnosticableTree > Widget > __StatelessWidget__

## Construtores

* SeniorButton({
    Key? key,
    required String label,
    bool disabled = false,
    required Function() onPressed,
    SeniorButtonType type = SeniorButtonType.primary,
    SeniorButtonSize size = SeniorButtonSize.small,
    bool fullLength = false,
}) ...  __const__

* SeniorButton.icon({
    Key? key,
    required String label,
    bool disabled = false,
    required Function() onPressed,
    required IconData icon,
    SeniorButtonType type = SeniorButtonType.primary,
    SeniorButtonSize size = SeniorButtonSize.small,
    bool fullLength = false,
}) ... __factory__

## Propriedades

| Property   | Type             | Description                                                                        | Required | Default                  |
| ---------- | ---------------- | ---------------------------------------------------------------------------------- | -------- | ------------------------ |
| key        | Key              | Controla como um widget substitui outro widget na árvore.                          | Não      | null                     |
| label      | String           | Texto do botão.                                                                    | Sim      |                          |
| icon       | IconData         | Ícone do botão.                                                                    | Sim      |                          |
| disable    | bool             | Determina se o botão estará desabilitado.                                          | Não      | false                    |
| onPressed  | Function()       | Função executada quando o botão for pressionado.                                   | Sim      |                          |
| type       | SeniorButtonType | Tipo do botão, podendo ser *primary*, *secondary*, *ghost*. Determina a aparência. | Não      | SeniorButtonType.primary |
| size       | SeniorButtonSize | Tamanho do botão, podendo ser *small* ou *big*                                     | Não      | SeniorButtonSize.small   |
| fullLength | bool             | Determina se o botão ocupará todo o espaço disponível.                             | Não      | false                    |

## Código

### Sem ícone

```dart
SeniorButton(
    label: 'Enviar',
    type: SeniorButtonType.primary,
    size: SeniorButtonSize.small,
    onPressed: () { print('Clique registrado'); },
    fullLength: true,
    disabled: false,
),
```

### Com ícone

```dart
SeniorButton.icon(
    label: 'Enviar',
    icon: FontAwesomeIcons.paperPlane,
    type: SeniorButtonType.primary,
    size: SeniorButtonSize.big,
    onPressed: () { print('Clique registrado'); },
),
```