import 'package:flutter/material.dart';
import 'package:badges/badges.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorBottomNavigationBarTheme {
  SeniorBottomNavigationBarTheme._();

  static Color getSelectedItemColor() {
    return SeniorColors.primaryColor;
  }

  static Color getUnselectedItemColor() {
    return SeniorColors.neutralColor500;
  }
}

class SeniorBottomNavigationBarItem {
  final IconData icon;
  final IconData? activeIcon;
  final String label;
  final String? badgeInfo;

  const SeniorBottomNavigationBarItem({
    required this.icon,
    this.activeIcon,
    required this.label,
    this.badgeInfo,
  });
}

class SeniorBottomNavigationBar extends StatelessWidget {
  final List<SeniorBottomNavigationBarItem> items;
  final Function(int) onTap;
  final int currentIndex;

  const SeniorBottomNavigationBar({
    Key? key,
    required this.items,
    required this.onTap,
    required this.currentIndex,
  }) : super(key: key);

  Widget buildIcon({required IconData icon, String? badgeInfo}) {
    return badgeInfo != null
        ? Badge(
            elevation: 0,
            badgeColor: SeniorColors.primaryColor400,
            badgeContent: Text(
              badgeInfo,
              style: SeniorTypography.small(
                color: SeniorColors.neutralColor900,
              ),
            ),
            child: FaIcon(icon),
          )
        : FaIcon(icon);
  }

  List<BottomNavigationBarItem> buildBottomNavBarItems() {
    List<BottomNavigationBarItem> bottomNavItems = [];

    this.items.forEach((item) {
      bottomNavItems.add(
        BottomNavigationBarItem(
          icon: buildIcon(
            icon: item.icon,
            badgeInfo: item.badgeInfo,
          ),
          activeIcon: buildIcon(
            icon: item.activeIcon ?? item.icon,
            badgeInfo: item.badgeInfo,
          ),
          label: item.label,
          backgroundColor: SeniorColors.pureWhite,
        ),
      );
    });

    return bottomNavItems;
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      child: BottomNavigationBar(
        key: this.key,
        type: BottomNavigationBarType.fixed,
        items: this.buildBottomNavBarItems(),
        currentIndex: this.currentIndex,
        iconSize: SeniorTypographyIconSize.h4,
        showSelectedLabels: true,
        selectedLabelStyle: SeniorTypography.small(color: SeniorBottomNavigationBarTheme.getSelectedItemColor()),
        selectedItemColor: SeniorBottomNavigationBarTheme.getSelectedItemColor(),
        showUnselectedLabels: true,
        unselectedLabelStyle: SeniorTypography.small(color: SeniorBottomNavigationBarTheme.getUnselectedItemColor()),
        unselectedItemColor: SeniorBottomNavigationBarTheme.getUnselectedItemColor(),
        onTap: this.onTap,
      ),
      height: 56.0,
    );
  }
}
