import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

class SeniorCard extends StatelessWidget {
  final Widget content;
  final Function()? pushAction;
  final Color? severityColor;

  const SeniorCard({
    Key? key,
    required this.content,
    this.pushAction,
    this.severityColor,
  }) : super(key: key);

  factory SeniorCard.checkbox({
    Key key,
    required Widget content,
    required bool value,
    Function() pushAction,
    Color? severityColor,
    required Function(bool?) onCheck,
  }) = _SeniorCardCheckbox;

  Widget buildCard() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        this.content,
        GestureDetector(
          onTap: this.pushAction,
          child: Icon(
            FontAwesomeIcons.chevronRight,
            color: SeniorColors.neutralColor600,
            size: SeniorTypographyIconSize.body,
          ),
        ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return SeniorElevatedElement(
      borderRadius: 6.0,
      elevation: SeniorElevations.dp01,
      child: Container(
        padding: EdgeInsets.only(left: 12.0),
        decoration: BoxDecoration(
          color: this.severityColor ?? SeniorColors.neutralColor100,
          borderRadius: BorderRadius.circular(6.0),
        ),
        child: Container(
          padding: const EdgeInsets.only(
            top: 16.0,
            bottom: 16.0,
            left: 8.0,
            right: 16.0,
          ),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.only(
              topRight: Radius.circular(6.0),
              bottomRight: Radius.circular(6.0),
            ),
            color: SeniorColors.neutralColor100,
          ),
          child: buildCard(),
        ),
      ),
    );
  }
}

class _SeniorCardCheckbox extends SeniorCard {
  final bool value;
  final Function(bool?) onCheck;

  _SeniorCardCheckbox({
    Key? key,
    required Widget content,
    required this.value,
    Function()? pushAction,
    Color? severityColor,
    required this.onCheck,
  }) : super(
          key: key,
          content: content,
          pushAction: pushAction,
          severityColor: severityColor,
        );

  @override
  Widget buildCard() {
    return Stack(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            this.content,
            Visibility(
              visible: this.pushAction != null,
              child: GestureDetector(
                onTap: this.pushAction,
                child: Icon(
                  FontAwesomeIcons.chevronRight,
                  color: SeniorColors.neutralColor600,
                  size: SeniorTypographyIconSize.body,
                ),
              ),
            ),
          ],
        ),
        Align(
          alignment: Alignment.topRight,
          child: SeniorCheckbox(
            value: this.value,
            onChanged: this.onCheck,
          ),
        ),
      ],
    );
  }
}
